summaryrefslogtreecommitdiff
path: root/src/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/config.h')
-rw-r--r--src/config.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/config.h b/src/config.h
index f5855113f..a1d8f7d23 100644
--- a/src/config.h
+++ b/src/config.h
@@ -66,18 +66,19 @@ extern int git_config__get_bool_force(
extern int git_config__get_int_force(
const git_config *cfg, const char *key, int fallback_value);
/* API for repository cvar-style lookups from config - not cached, but
* uses cvar value maps and fallbacks
*/
-extern int git_config__cvar(
- int *out, git_config *config, git_cvar_cached cvar);
+extern int git_config__configmap_lookup(
+ int *out, git_config *config, git_configmap_item item);
/**
* The opposite of git_config_lookup_map_value, we take an enum value
* and map it to the string or bool value on the config.
*/
-int git_config_lookup_map_enum(git_cvar_t *type_out, const char **str_out,
- const git_cvar_map *maps, size_t map_n, int enum_val);
+int git_config_lookup_map_enum(git_configmap_t *type_out,
+ const char **str_out, const git_configmap *maps,
+ size_t map_n, int enum_val);
/**
* Unlock the backend with the highest priority
@@ -66,18 +66,19 @@ extern int git_config__get_bool_force(
extern int git_config__get_int_force(
const git_config *cfg, const char *key, int fallback_value);
-/* API for repository cvar-style lookups from config - not cached, but
- * uses cvar value maps and fallbacks
+/* API for repository configmap-style lookups from config - not cached, but
+ * uses configmap value maps and fallbacks
*/